const webpack = require('webpack');
const path = require('path');
const projectRoot = path.resolve(__dirname, '../');

module.exports = {
  entry: './docs/index.js',
  output: {
    path: './build',
    publicPath: 'build/',
    filename: 'vue-t-ui-docs.js'
  },
  resolve: {
    root: path.resolve('./')
  },
  module: {
    preLoaders: [
      {
        test: /\.(vue|js)$/,
        loader: 'eslint',
        include: projectRoot,
        exclude: /node_modules/
      }
    ],
    loaders: [
      { test: /\.vue$/, loader: 'vue' },
      {
        test: /\.js$/,
        exclude: /node_modules|vue\/src|vue-loader\//,
        loader: 'babel'
      },
      { test: /\.css$/, loader: "style-loader!css-loader?root=./docs/" },
      { test: /\.scss$/, loader: "style!css!sass" },
      { test: /\.less$/, loader: "style-loader!css-loader!less-loader" },
      { test: /\.html$/, loader: 'vue-html' },
      {
        test: /\.(png|jpe?g|gif)(\?.*)?$/,
        loader: 'url',
        query: {
          limit: 10000,
          name: 'assets/img/[hash].[ext]'
        }
      },
      {
        test: /\.eot(\?.*?)?$/,
        loader: 'file',
        query: {
          limit: 10000,
          name: 'asset/font/[hash].[ext]'
        }
      },
      {
        test: /\.woff2?(\?.*?)?$/,
        loader: 'file',
        query: {
          limit: 10000,
          mimetype: 'application/application/font-woff',
          name: 'asset/font/[hash].[ext]'
        }
      },
      {
        test: /\.ttf(\?.*?)?$/,
        loader: 'file',
        query: {
          limit: 10000,
          mimetype: 'application/octet-stream',
          name: 'asset/font/[hash].[ext]'
        }
      },
      {
        test: /\.svg(\?.*?)?$/,
        loader: 'file',
        query: {
          limit: 10000,
          mimetype: 'image/svg+xml',
          name: 'asset/font/[hash].[ext]'
        }
      }
    ]
  },
  babel: {
    presets: ['es2015'],
    plugins: ['transform-runtime']
  },
  devtool: 'source-map'
};

if (process.env.NODE_ENV === 'production') {
  delete module.exports.devtool;
  module.exports.plugins = [
    new webpack.DefinePlugin({
      'process.env': {
        NODE_ENV: '"production"'
      }
    }),
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        warnings: false
      }
    })
  ];
}
